
import { GUID } from "./sgiCommonConstant"

/**
 * 指定长度和进制的UUID
 * @param len       长度
 * @param radix     进制，2,8,10,16
 * @returns {string}
 */
function uuid(len, radix) {
    var chars = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'.split('');
    var uuid = [],
        i;
    radix = radix || chars.length;

    if (len) {
        // Compact form
        for (i = 0; i < len; i++)
            uuid[i] = chars[0 | Math.random() * radix];
    }
    else {
        // rfc4122, version 4 form
        var r;

        // rfc4122 requires these characters
        uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-';
        uuid[14] = '4';

        // Fill in random data. At i==19 set the high bits of clock sequence as per
        // rfc4122, sec. 4.1.5
        for (i = 0; i < 36; i++) {
            if (!uuid[i]) {
                r = 0 | Math.random() * 16;
                uuid[i] = chars[(i == 19)
                    ? (r & 0x3) | 0x8
                    : r];
            }
        }
    }

    return uuid.join('');
}

function getJsonLength(jsonData) {
    var length = 0;
    for (var ever in jsonData) {
        length++;
    }
    return length;
}


function copyArr(arr, flag) {
    let res = []
    for (let i = 0; i < arr.length; i++) {
        let tmp;
        if (flag) {
            tmp = copy(arr[i], true);
        } else {
            tmp = arr[i];
        }
        res.push(tmp);
    }
    return res;
}

/**
 * 拷贝 包括深浅拷贝
 * @param {*} obj
 * @param {*} flag 是否深拷贝
 */
function copy(obj, flag) {
    if (flag) {
        return deepCopy(obj);
    }
    var newobj = {};
    for (var attr in obj) {
        newobj[attr] = obj[attr];
    }
    return newobj;
}

function getType(obj) {
    //tostring会返回对应不同的标签的构造函数
    var toString = Object.prototype.toString;
    var map = {
        '[object Boolean]': 'boolean',
        '[object Number]': 'number',
        '[object String]': 'string',
        '[object Function]': 'function',
        '[object Array]': 'array',
        '[object Date]': 'date',
        '[object RegExp]': 'regExp',
        '[object Undefined]': 'undefined',
        '[object Null]': 'null',
        '[object Object]': 'object'
    };
    if (obj instanceof Element) {
        return 'element';
    }
    return map[toString.call(obj)];
}

function deepCopy(data) {
    var type = getType(data);
    var obj;
    if (type === 'array') {
        obj = [];
    } else if (type === 'object') {
        obj = {};
    } else {
        //不再具有下一层次
        return data;
    }
    if (type === 'array') {
        for (var i = 0, len = data.length; i < len; i++) {
            obj.push(deepCopy(data[i]));
        }
    } else if (type === 'object') {
        for (var key in data) {
            obj[key] = deepCopy(data[key]);
        }
    }
    return obj;
}

/**
 * function 函数也转
 *
 * @param json
 * @returns
 */
function jsonToStr(json) {
    var retrunVal;
    if (typeof json === "object") {
        retrunVal = JSON.stringify(json);
        return retrunVal;
    }
    return json;
}

function strToJson(str) {
    var json;
    if (typeof str != "object") {
        json = JSON.parse(str);
        return json;
    }
    return str;
}

function getAP(guid) {
    if (!guid) {
        return "";
    }
    var elems = getWords(guid, GUID.SP);
    if (!elems || elems.length != 4) {
        return "";
    }
    return elems[0];
}
/*
 * 根据指定的分隔符，将一个字符串分割为字符串数组 str -- 输入参数，需要分解的字符串 spt --
 * 输入参数，分隔符，允许多个，例如：',' 和 ‘.' 都是分隔符，spt = ",." 返回 字符串数组
 */
function getWords(str, spt) {
    if (!str)
        return null;
    if (!spt)
        return [str];
    if (typeof str != 'string')
        return [];
    if (typeof spt != 'string')
        return [str];
    var sptExp = new RegExp("[" + spt + "]"); // 分隔符匹配正则表达式，separator
    // regular expression
    return str.split(sptExp);
}
/**
* 从树结构的json中取得json数据的最底层
*
* @returns {undefined}
*/
function getLeafByPrm(treeJson) {
    var array = [];
    if (!treeJson) {
        return array;
    }
    var sGuid = [];
    var fn = function (node, sGuid) {
        var children = node.cldSet;
        if (children) {
            children.forEach(c => {
                var cCld = c.cldSet;
                var sc = c.sc;
                sGuid.push(sc);
                if (cCld) {
                    fn(c, sGuid);
                } else {
                    c.sc = sGuid.join("`");
                    array.push(c);
                }
                sGuid.pop(sc);
            });
        }
    }
    fn(treeJson, sGuid);
    return array;
}

// 根据parm的json对象转化成获得treeModel对象
function cvtTreeByPrm(data) {
    if (!data) {
        return new Ext.data.TreeModel();
    }
    // 取得该数据的描述
    var guid = data.desId;
    // var eod = Ep.PrmFactory.getPrmJson(guid);
    // if (!eod) {
    // return new Ext.data.TreeModel();
    // }
    // 定义该类，创建该类对象
    var cNClass = this.defineTMByEod(guid);
    if (!cNClass) {
        return new Ext.data.TreeModel();
    }
    var root = this.createTreeObj(cNClass, data);
    this.addChilds(root, data.cldSet);
    // 删除root中的cldSet属性,该属性只是后面创建节点信息，不属于本身信息
    delete root.data.cldSet;
    return root;
}

let Array = {
    removeIndex: function (array, index) {
        if (!array || array.length == 0) {
            return;
        }
        if (index == undefined || index == null) {
            return;
        }
        array.splice(index, 1);
    },
    remove: function (array, obj) {
        if (!array || array.length == 0) {
            return;
        }
        if (obj == undefined || obj == null) {
            return;
        }
        for (var i = 0; i < array.length; i++) {
            var tmp = array[i];
            if (tmp == obj) {
                array.splice(i, 1);
            }
        }
    },
    removeJson: function (array, key, value) {
        if (!array || array.length == 0) {
            return;
        }
        if (!key || !value) {
            return;
        }
        for (var i = 0; i < array.length; i++) {
            var tmp = array[i];
            if (typeof tmp == "object") {
                if (tmp[key] === value) {
                    array.splice(i, 1);
                }
            }
        }
    }
}

export { uuid, jsonToStr, strToJson, getAP, getLeafByPrm, copy, Array, copyArr, getJsonLength }
