/*  控件常用监听操作
 归属：企通前端平台-ECP V5.1
 版权：2014-2020 企通软件技术有限公司
 --------------------------------------------------------------------------------
 作者：王哲                           创建日期：2014/03/24
 修改：                               修改日期：
 修改内容
 --------------------------------------------------------------------------------
 常用控件的监听程序：包括
 进入事件
 变更事件
 离开事件
 点击事件
 表格点击事件
 树控件点击事件
 *******************************************************************************/
import { sgiLogger } from '../sgiCommon/sgiLogger';
import { AllCompGUID } from "./SgiCompConstant";
import { sgiTreeNodeFun } from "./SgiTreeBaseFun"



var SgiEventHandler = {
    /**
     * 点击事件
     *
     * @param {type}
     *            ctl 控件本身
     * @param {type}
     *            eo 事件
     */
    onClick: function (eo) {
        try {
            sgiLogger.eventin(eo);
            var { objFct } = this.props;
            let onClick = this.state.functions.onClick;
            if (onClick) {
                onClick(this, objFct);
            }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 进入事件
     *
     * @param {type}
     *            ctl 控件本身
     * @param {type}
     *            eo 事件
     */
    onFocus: function (currentModule, eo) {
        try {
            sgiLogger.eventin(eo);
            var { objFct } = currentModule.props;
            let onFocus = currentModule.state.functions.onFocus;
            if (onFocus) {
                onFocus(currentModule, objFct);
            }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 焦点离开监听
     *
     * @param {type}
     *            ctl 控件本身
     * @param {type}
     *            eo 事件
     */
    onBlur: function (currentModule, eo) {
        try {
            sgiLogger.eventin(eo);
            var { objFct } = currentModule.props;
            let onBlur = currentModule.state.functions.onBlur;
            if (onBlur) {
                onBlur(currentModule, objFct);
            }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 修改监听
     *
     * @param {type}
     *            ctl 控件
     * @param {type}
     *            nV 新值
     * @param {type}
     *            oV 旧值
     * @returns {undefined}
     */
    onChange: function (currentModule, e, e2) {
        try {
            console.log("change进入");
            var { moduleDesc, bdInst, objFct, type } = currentModule.props;
            var mdType = moduleDesc.desId;
            var newvalue;
            if (mdType === AllCompGUID.DATE) {
                newvalue = handleOnSelDate(currentModule, moduleDesc.c, bdInst, objFct, e, e2, moduleDesc.dateFmt);
            } else if (mdType === AllCompGUID.NUMBER) {
                newvalue = handleOnNumberChange(currentModule, moduleDesc.c, bdInst, objFct, e);
            } else if (mdType === AllCompGUID.TIME) {
                newvalue = handleOnSelTime(currentModule, moduleDesc.c, bdInst, objFct, e, e2, moduleDesc.dateFmt);
            } else if (mdType === AllCompGUID.UPLOADFILE) {
                newvalue = handleOnFileChange(currentModule, moduleDesc.c, bdInst, objFct, e, e2, moduleDesc.dateFmt);
            } else if (mdType === AllCompGUID.CHECKBOX || mdType === AllCompGUID.CHECKBOXGROUP) {
                newvalue = handleCheckBoxChange(currentModule, moduleDesc.c, bdInst, objFct, e);
            } else if (mdType === AllCompGUID.COMBOXTREE || mdType === AllCompGUID.COMBOXTREE) {
                newvalue = handleOnTreeSelectChange(currentModule, moduleDesc.c, bdInst, objFct, e);
            } else if (mdType === AllCompGUID.COMBOBOX) {
                //多选的时候 e是选中事件还是取消选中的标志
                newvalue = handleOnComboxChange(currentModule, moduleDesc.c, bdInst, objFct,e);
            } else {
                //调用统一  修改事件
                newvalue = handleOnChange(currentModule, moduleDesc.c, bdInst, objFct, e);
            }

            //调用自定义事件
            let onChange = currentModule.state.functions.onChange;
            if (onChange) {
                sgiLogger.eventin('修改');
                onChange(currentModule, objFct, newvalue, objFct.get(bdInst));
            }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 菜单控件 MenuItem 点击事件
     * @param  {[type]} item [description]
     * @return {[type]}      [description]
     */
    menuClick: function (item) {
        try {
            // console.log(arguments);
            // console.log("menuClick:", item);
            var { objFct } = this.props;
            let onClick = this.state.functions.onClick;
            if (onClick) {
                onClick(this, objFct, item);
            }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 弹出窗自定义单击监听
     * @param  {[type]} value [description]
     * @return {[type]}       [description]
     */
    onSearch: function (value) {
      try {
          console.log(arguments);
          console.log("onSearch:", value);
          var { objFct } = this.props;
          let onSearch = this.state.functions.onSearch;
          if (onSearch) {
              onSearch(this, objFct, value);
          }
      } catch (error) {
          sgiLogger.error(error);
      }
    },
    /**
     * 表格、树选择监听
     *
     * @param {type}
     *            ctl
     * @param {type}
     *            r
     * @param {type}
     *            index
     * @returns {undefined}
     */
    select: function (ctl, r, index) {
        try {
            console.log(arguments);
            console.log(this.state.functions);
            let tcl = this.state.functions.tab;
            if (tcl) {
                tcl();
            }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 树单击监听
     *
     * @param {type}
     *            selectedKeys
     * @param {type}
     *            info
     * @returns {undefined}
     */
    itemclick: function (selectedKeys, e) {
        try {
          this.state.selectedKeys = selectedKeys;
          this.state.checkedKeys = selectedKeys;
          this.setState({ loading: false });
          console.log('selected', selectedKeys, e);

          //非多选,找到选中节点
          if (e && e.event == "select") {
            this.state.selectedNodes = [e.node.props.itemData];
          }else {//多选
            var checkedNodes = e.checkedNodes;
            if (checkedNodes && checkedNodes.length > 0) {
              this.state.selectedNodes = [];
              for (var i = 0; i < checkedNodes.length; i++) {
                var node = checkedNodes[i].props.itemData;
                this.state.selectedNodes.push(node);
              }
            }
          }
          //当前操作节点，当前treeNode
          var record = e.node.props.itemData;
          var treeNode = e.node.props;

          console.log("record", record);
          var { objFct } = this.props;
          let onSelect = this.state.functions.onSelect;
          if (onSelect) {
              onSelect(this, objFct, record, treeNode, e);
          }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 表格单击监听
     *
     * @param {type} 当前选中行对象
     *            record
     * @param {type} 行序号/索引，从0开始
     *            index
     * @returns {undefined}
     */
    tableClick: function (record, index) {
        try {
          console.log('表格单击事件', record, index);
          //console.log('arguments',arguments);
          //console.log(this.state.functions);
          this.setState({selectedRows : [record]});
          var { objFct } = this.props;
          let onRowClick = this.state.functions.onRowClick;
          if (onRowClick) {
              onRowClick(this, objFct, record, index);
          }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 双击监听
     *
     * @param {type}
     *            ctl
     * @param {type}
     *            r
     * @param {type}
     *            item
     * @param {type}
     *            ind
     * @returns {undefined}
     */
    itemdblclick: function (ctl, r, item, ind) {
        try {
            console.log(arguments);
            console.log(this.state.functions);
            let tcl = this.state.functions.tab;
            if (tcl) {
                tcl();
            }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 选项卡切换监听器
     *
     * @param {object}
     *            ctn 容器对象
     * @returns {undefined}
     */
    tcl: function (activeKey) {
        try {
            var { objFct } = this.props;
            this.setState({ activeKey });
            let tcl = this.state.functions.tab;
            if (tcl) {
                tcl(this,objFct,activeKey);
            }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 层叠面板展开事件监听器
     *
     * @param {object}
     *            ctn 容器对象
     * @returns {undefined}
     */
    expd: function (key) {
        try {
          console.log('折叠面板事件', key);
          console.log('arguments',arguments);
          var { objFct } = this.props;
          this.setState({ activeKey: key });
          let expandLsn = this.state.functions.expandLsn;
          if (expandLsn) {
              expandLsn(this, objFct, key);
          }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
    * 页面后处理事件
    *
    * @param {object}
    *            ctn 容器对象
    * @returns {undefined}
    */
    ctnAfter: function (ctn) {
        try {
            console.log(arguments);
            console.log(this.state.functions);
            let tcl = this.state.functions.tab;
            if (tcl) {
                tcl();
            }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 页面关闭事件监听器
     *
     * @param {object}
     *            ctn 容器对象
     * @returns {undefined}
     */
    ctnCls: function (e) {
        try {
          console.log('弹出窗关闭事件', e);
          var { objFct } = this.props;
          let afterClose = this.state.functions.afterClose;
          if (afterClose) {
              afterClose(this, objFct, e);
          }
        } catch (error) {
            sgiLogger.error(error);
        }
    },
    /**
     * 页面销毁前事件监听器
     *
     * @param {object}
     *            ctn 容器对象
     * @returns {undefined}
     */
    ctnBfRmv: function (ctn) {
        try {

        } catch (error) {

        }
    },
    /**
     * 页面初始化监听器
     *
     * @param {object}
     *            ctn 容器对象
     * @returns {undefined}
     */
    init: function (ctn) {
        try {

        } catch (error) {

        }
    },
    /**
     * 菜单前处理监听器
     *
     * @param {object}
     *            ctn 容器对象
     * @returns {undefined}
     */
    onbfsw: function (ctn) {
        try {

        } catch (error) {

        }
    },
    /**
     * 页面折叠监听器
     *
     * @param {object}
     *            ctn 容器对象
     * @returns {undefined}
     */
    clp: function (ctn) {
        try {

        } catch (error) {

        }
    }

}



/**
 * form下控件的通过用change事件
 * @param {控件绑定属性名称} attname
 * @param {form绑定的数据key} bdInst
 * @param {对象工厂} objFct
 * @param {事件描述} e
 */
var handleOnChange = function (currentModule, attname, bdInst, objFct, e) {
    var value = e.target.value;
    currentModule.ctlRefresh(attname, bdInst, objFct, value);
    return value;
}
/**
* form下文件控件的通过用change事件
* @param {控件绑定属性名称} attname
* @param {form绑定的数据key} bdInst
* @param {对象工厂} objFct
* @param {事件描述} e
*/
var handleOnFileChange = function (currentModule, attname, bdInst, objFct, e) {
    var value = e.file;
    currentModule.ctlRefresh(attname, bdInst, objFct, value);
    return value;
}
/**
 * form下checkbox控件的通过用change事件
 * @param {控件绑定属性名称} attname
 * @param {form绑定的数据key} bdInst
 * @param {对象工厂} objFct
 * @param {事件描述} e
 */
var handleCheckBoxChange = function (currentModule, attname, bdInst, objFct, e) {
    var value = e;
    var disValue ;
    if(value && value.length>1){
        for (let i = 0; i < value.length; i++) {
            const element = value[i];
            disValue= value.join(",")
        }
    }else{
        disValue = value[0];
    }
    currentModule.ctlRefresh(attname, bdInst, objFct, disValue);
    return e;
}
/**
* form下数字控件的通过用change事件
* @param {控件绑定属性名称} attname
* @param {form绑定的数据key} bdInst
* @param {对象工厂} objFct
* @param {事件描述} e
*/
var handleOnNumberChange = function (currentModule, attname, bdInst, objFct, e) {
    var value = e;
    currentModule.ctlRefresh(attname, bdInst, objFct, value);
    return value;
}
/**
* form下数字控件的通过用change事件
* @param {控件绑定属性名称} attname
* @param {form绑定的数据key} bdInst
* @param {对象工厂} objFct
* @param {事件描述} e
*/
var handleOnComboxChange = function (currentModule, attname, bdInst, objFct, value) {
    var value = value;
    // if (mode=='onSelect'){
    //     //如果是选中,真事数据中 添加这个值，否则取消这个值
    //     currentModule.state.showValue.push(value);
    //     value = currentModule.state.showValue;
    // } else if(mode=='onDeselect'){

    // }
    var disValue ;
    if(value && value.length>1){
        for (let i = 0; i < value.length; i++) {
            const element = value[i];
            disValue= value.join(",")
        }
    }else{
        disValue = value[0];
    }
    // console.log(1111111111111111111111111111111);
    currentModule.ctlRefresh(attname, bdInst, objFct, disValue);
    return value;
}
/**
 * form下日期控件的通过用change事件
 * @param {控件绑定属性名称} attname
 * @param {form绑定的数据key} bdInst
 * @param {对象工厂} objFct
 * @param {更新后的值date格式} date
 * @param {更新后的值string格式} dateString
 * @param {格式} dateFormat
 */
var handleOnSelDate = function (currentModule, attname, bdInst, objFct, date, dateString, dateFormat) {

    if (dateString == null || dateString.length == 0) {
        dateString = '';
    }
    //格式化 以后再说
    currentModule.ctlRefresh(attname, bdInst, objFct, date);
    return date;
}
/**
 * form下时间控件的通过用change事件
 * @param {控件绑定属性名称} attname
 * @param {form绑定的数据key} bdInst
 * @param {对象工厂} objFct
 * @param {更新后的值date格式} Time
 * @param {更新后的值string格式} timeString
 * @param {格式} TimeFormat
 */
var handleOnSelTime = function (currentModule, attname, bdInst, objFct, time, timeString, TimeFormat) {
    // if (dateString == null || dateString.length == 0) {
    //     dateString = '';
    // }
    //格式化 以后再说
    currentModule.ctlRefresh(attname, bdInst, objFct, time);
    return time;
}
/**
* 下拉树的通过用change事件
* @param {控件绑定属性名称} attname
* @param {form绑定的数据key} bdInst
* @param {对象工厂} objFct
* @param {事件描述} e
*/
var handleOnTreeSelectChange = function (currentModule, attname, bdInst, objFct, e) {
    var value = e;
    var disValue ;
    var multiple = currentModule.state.inputprops.multiple;// 是否多选
    if (multiple == true) {
        if(value && value.length>1){
            for (let i = 0; i < value.length; i++) {
                const element = value[i];
                disValue= value.join(",")
            }
        }else{
            disValue = value[0];
        }
    } else {
        disValue = value;
    }

    currentModule.ctlRefresh(attname, bdInst, objFct, disValue);
    return value;
}

export { SgiEventHandler }
