import React from 'react';
import ReactDOM from 'react-dom';
import { Form, Input, DatePicker, Col, TimePicker, Select, Cascader, InputNumber } from 'antd';
// import { text_mk } from '../common/UBCtlMaker';
import { ObjFactory } from '../sgiFactory/ObjFactory';
import { convertModuleByGuid } from "./SgiCompComm";
import { sgiLogger } from '../sgiCommon/sgiLogger';
import { Resource } from '../sgiCommon/Resource';
import { PrmFactory } from '../sgiFactory/PrmFactory'
import { uuid } from '../sgiCommon/sgiCommon'
const FormItem = Form.Item;

class SgiMainComp extends React.Component {

    constructor(props) {
        super(props);
        this.state = {
            loading: false,
            loaded: false,
            mainUIProps: { style: { height: '100%', width: '100%' } },
            mainUIItems: [],
            modalItems: [],
            modalInstanceItems: []
        };
    }

    /**
   * 根据描述创建form
   * @param {父组件} panelModule
   * @param {描述} moduleDesc
   * @param {对象工厂} objFct
   * @param {make类型} type
   */
    main_mk(panelModule, moduleDesc, objFct, type) {
        //获取需要展示的数据信息
        if (!moduleDesc) {
            return;
        }
        //传入的对象工厂是否为空
        if (!objFct) {
            return;
        }

        this.state.mainUIItems = []; //再次渲染的时候清空

        //转换基础属性
        this.AddAttribute(moduleDesc, this.state.mainUIProps);
        //组装form表单下的控件信息
        this.fitMainUIItems(moduleDesc, this.state.mainUIItems, objFct, type);
    }

    /**
     * 属性转换
     * @param {描述信息} moduleDesc
     * @param {属性} formProps
     */
    AddAttribute = function (moduleDesc, mainUIProps) {
        var cId = moduleDesc.cId; //cid 唯一标示
        if (cId) mainUIProps.id = cId;

        var ctlW = moduleDesc.ctlW; //form宽度
        if (ctlW) mainUIProps.style.width = ctlW;

        var ctlH = moduleDesc.ctlH; //form高度
        if (ctlH) mainUIProps.style.height = ctlH;

        var text = Resource.getTRByPrm(moduleDesc).te; //form标题??没实现
        var ttlAlgn = moduleDesc.ttlAlgn; //form标题对齐方式??没实现
        var icon = moduleDesc.icon; //form背景图片??没实现
        var bdsty = moduleDesc.bdsty; //form背景颜色??没实现
        var isTtl = moduleDesc.isTtl; //form是否显示标题??没实现
        var ttlAlg = moduleDesc.ttlAlg; //form标题位置??没实现
        var isCls = moduleDesc.isCls; //form是否可以关闭??没实现
        var isFrm = moduleDesc.isFrm; //form是否填充??没实现-----del
        var isScl = moduleDesc.isScl; //form是否可以滚动??没实现
        var html = moduleDesc.html; //form显示html元素??没实现----del
        var isHdn = moduleDesc.isHdn; //form是否隐藏??没实现
        var isDis = moduleDesc.isDis; //form是否禁用??没实现
        var mgn = moduleDesc.mgn; //form外边距??没实现
        var pad = moduleDesc.pad; //form内边距??没实现
        var csstyle = moduleDesc.csstyle; //form样式??没实现
        var flx = moduleDesc.flx; //form占比??没实现
        var isBrdr = moduleDesc.isBrdr; //form是否有边框??没实现
    }

    /**
     * 根据描述组装子对象
     * @param {描述信息} moduleDesc
     * @param {属性} formProps
     */
    fitMainUIItems = function (moduleDesc, mainUIItems, objFct, type) {
        var me = this;

        //form下的子节点添加到form组件中
        let cldSet = moduleDesc.cldSet;
        if (cldSet && cldSet.length && cldSet.length > 0) {
            cldSet.forEach((item, index) => {
                let tmpSonComp = convertModuleByGuid(me, item, null, objFct, type);
                if (tmpSonComp) {
                    mainUIItems.push(tmpSonComp);
                }
            });

        }
    }

    //render之前调用，业务逻辑都应该放在这里，如对state的操作等
    componentWillMount = function () {
        //添加页面初始化监听器
        let { moduleDesc, objFct } = this.props;
        if (!moduleDesc || !objFct) {
            return;
        }
        var initLsn = moduleDesc.initLsn;// 页面初始化监听器
        if (initLsn) {
            sgiLogger.eventin('初始化');
            var initFn = new Function("module", "objFct", initLsn);
            try {
                initFn(this, objFct);
            } catch (error) {
                sgiLogger.error(error);
            }
        }
    }


    //该方法发生在render方法之后。在该方法中，ReactJS会使用render生成返回的虚拟DOM对象来创建真实的DOM结构
    componentDidMount = function () {
        console.log('SgiMainCompcomponentDidMount');
        //添加页面初始化监听器
        let { moduleDesc, objFct } = this.props;
        if (!moduleDesc || !objFct) {
            return;
        }
        var initAftLsn = moduleDesc.initAftLsn;// 页面加载后监听器
        if (initAftLsn) {
            sgiLogger.eventin('加载后');
            var initAftLsn = new Function("module", "objFct", initAftLsn);
            try {
                initAftLsn(this, objFct);
            } catch (error) {
                sgiLogger.error(error);
            }
        }
        //将所有引用 都放入到统一Manager里面管理起来
        this.fitComponentManager(this.refs, objFct.getUID());
        //把自己放进去 将所有引用 都放入到统一Manager里面管理起来
        ComponentManager.set(objFct.getUID(), PrmFactory.makeGUID(moduleDesc), this);
    }

    fitComponentManager = (refs, uid) => {
        let itemRef;
        for (var itemRefKey in refs) {
            itemRef = refs[itemRefKey];
            ComponentManager.set(uid, itemRefKey, itemRef);
            if (itemRef.refs) {
                this.fitComponentManager(itemRef.refs, uid);
            }
        }
    };

    refresh() {
        this.state.loaded = false;
        this.setState({ loading: false });
    }

    removeModal() {
        this.state.modalItems.pop();
        this.state.modalInstanceItems.pop();
    }

    addModal(modal) {
        if (!modal) {
            return;
        }
        this.state.modalItems.push(modal);
    }

    /**
     * 获取加载后的 组件
     */
    getModal() {
        if (!this.state.modalInstanceItems.length) {
            return;
        }
        return this.state.modalInstanceItems[this.state.modalInstanceItems.length - 1];
    }

    /**
     * 设置加载后的 组件
     * @param {*} modal
     */
    setModal(modal) {
        if (!modal) {
            return;
        }
        this.state.modalInstanceItems.push(modal);
    }

    //渲染并返回一个虚拟DOM
    render = function () {
        // this.load = false;
        if (!this.state.loaded) {
            let { panelModule, moduleDesc, objFct, type } = this.props;
            //组装属性
            this.main_mk(panelModule, moduleDesc, objFct, type);
            this.state.loaded = true;
        }

        return (
            <div {...this.state.mainUIProps}>
                {this.state.mainUIItems}
                {this.state.modalItems}
                {this.props.children}
            </div>
        );
    }
}

export { SgiMainComp };
