import React from 'react';
import ReactDOM from 'react-dom';
import { Table, Input, Form, Pagination, Icon, Button } from 'antd';
import { addCtnCommonAttribute } from "./SgiCtnComm"
import { convertModuleByGuid } from "./SgiCompComm"
import { sgiFormCtlBaseFun } from "./sgiFormCtlBaseFun"
const FormItem = Form.Item;
import { PrmFactory } from '../sgiFactory/PrmFactory'
import { Resource } from '../sgiCommon/Resource';
import { SgiEventHandler } from './SgiEventHandler';
import { copy, copyArr } from '../sgiCommon/sgiCommon'

class SgiTable extends React.Component {

    static defaultProps = {
        // type: 'N',
    };  // 注意这里有分号
    static propTypes = {
    };  // 注意这里有分号

    constructor(props) {
        super(props);
        this.state = {
            loading: false,
            pagination: {},//分页信息
            size: 'default',
            expandedRowRender: [], //展开列
            footer: {},
            rowSelection: null, //选择属性
            scroll: undefined,
            columns: [], //列信息
            tableProps: { style: {} }, //表格属性
            dataSource: [], //显示数据
            loading: false, //刷新属性
            // selectedRowKeys: [] //选择的列信息 //放入到了rowSelection中
            functions: {},
            selectedRows: [] //已选择/勾选的行对象数组
        };
    }

    /**
     * 根据描述创建表格
     * @param {父组件} panelModule
     * @param {组件描述} moduleDesc
     * @param {绑定实例ID} bdInst
     * @param {当前工作区} ws
     * @param {make类型} type
     */
    table_mk(panelModule, moduleDesc, bdInst, objFct, type) {

        //获取需要展示的数据信息
        var moduleDesc = this.props.moduleDesc;
        if (!moduleDesc) {
            return;
        }

        //取得绑定列描述信息
        var ClmDes = this.getClmDes(moduleDesc, ClmDes);
        //绑定数据，创建表格store 搜索条、翻页控件需要使用该信息，所以先创建
        var tableStore = this.getTBData(moduleDesc, objFct);
        this.state.dataSource = tableStore;
        //创建表头
        var clms = this.crtClmHead(moduleDesc, ClmDes, objFct, type);
        this.state.columns = clms ? clms : [];

        //添加表格列,拖拽页面自定义的表格列
        this.crtClmHeadDnd(moduleDesc, this.state.columns, type);

        //分页信息
        this.crtPgeBbar(moduleDesc, tableStore, objFct);
        //创建表格属性
        this.AddTBAttribute(moduleDesc, this.state.tableProps);
        //添加表格的选择模式
        this.crtTblSltModel(moduleDesc);
        //转换公共属性
        addCtnCommonAttribute(this, moduleDesc, this.state.tableProps);
        //绑定事件
        this.bindEvent(moduleDesc, this.state.tableProps, this.state.rowSelection, this.state.functions, type);
    }

    crtClmOptDnd(element, record, index) {
        let { btnName, btnIcon, optType, iCLsn } = element;
        let clickLsn;
        let optProp = { style: { margin: "0px 10px 0px 0px"} };
        if (iCLsn) {
            clickLsn = new Function("module", "objFct", "record", "index", iCLsn);
            optProp.onClick = clickLsn.bind(this, this, this.props.objFct, record, index);
        }
        let rtnOptInfo;
        if (!optType || optType == 'btn') {
            rtnOptInfo = <Button {...optProp} icon={btnIcon}>
                {btnName}
            </Button>
        } else if (optType == 'href') {
            rtnOptInfo = <a {...optProp} >
                {btnName}
                {btnIcon ? <Icon type={btnIcon} style={{ fontSize: 16, color: '#08c' }} /> : null}
            </a>
        }
        return rtnOptInfo;
    }

    /**
     * 添加表格列
     * @param {*} moduleDesc 
     * @param {*} columns 
     */
    crtClmHeadDnd(moduleDesc, columns, type) {
        if (moduleDesc && moduleDesc.dnd_columns && moduleDesc.dnd_columns.length > 0) {
            let dnd_columns = moduleDesc.dnd_columns;
            //拖拽的时候  拷贝一份数据，导致篡改了，拖拽的数组
            if (type = 'dnd') {
                dnd_columns = copyArr(moduleDesc.dnd_columns, true);
            }
            dnd_columns.forEach(element => {
                if (element.clmType == 'optGroup') {
                    let { children } = element;
                    if (!children || children.length < 1) {
                        return;
                    }
                    element.render = (text, record, index) => {
                        let optList = [];
                        children.forEach(sonElement => {
                            optList.push(this.crtClmOptDnd(sonElement, record, index));
                        })
                        return (
                            <span>
                                {optList}
                            </span>
                        )
                    }
                    delete element.children;
                } else if (element.clmType == 'opt') {
                    element.render = (text, record, index) => (
                        <span>
                            {this.crtClmOptDnd(element, record, index)}
                        </span>
                    )
                }
                columns.push(element);
            });
        }
    }

    /**
     * 绑定事件
     * @param {*} moduleDesc
     * @param {*} treeProps
     */
    bindEvent(moduleDesc, tableProps, rowSelection, functions, type) {
        //拖拽模式 不生成事件
        //表格单击事件
        var iCLsn = moduleDesc.iCLsn; // 用户自定义点击事件
        if (iCLsn && type != 'dnd') {
            var $iCLsn = new Function("module", "objFct", "record", "index", iCLsn);
            functions.onRowClick = $iCLsn;
        }
        tableProps.onRowClick = SgiEventHandler.tableClick.bind(this);


        if (!rowSelection) {
            return;
        }
        //onChange(selectedRowKeys, selectedRows):已勾选key数组，已勾选行对象数组
        //手动(取消)勾选/点击(取消)全选时触发，通过方法(取消)勾选不会触发
        rowSelection.onChange = (selectedRowKeys, selectedRows) => {
            this.setState({ selectedRows: selectedRows });
            this.state.rowSelection.selectedRowKeys = selectedRowKeys;
            this.setState({ loading: false });
            console.log(`selectedRowKeys changed: ${selectedRowKeys}`);
        }
        //onSelect(record, selected, selectedRows, nativeEvent):当前操作对象，勾选状态，已勾选行对象数组，
        //手动(取消)勾选时触发，点击(取消)全选时不会触发
        rowSelection.onSelect = (record, selected, selectedRows) => {
            this.setState({ selectedRows: selectedRows });
            console.log(record, selected, selectedRows);
        }
        //onSelectAll(selected, selectedRows, changeRows):勾选状态，已勾选行对象数组，勾选状态发生变化的对象数组（即全部数据）
        //点击(取消)全选时触发，手动一个一个勾选至(非)全选时不触发
        rowSelection.onSelectAll = (selected, selectedRows) => {
            this.setState({ selectedRows: selectedRows });
            console.log(selected, selectedRows);
        }

    }

    /**
     * 创建表格的选择模式
     * @param {TD} 表格描述
     * 创建表格选择模式使用表格以下属性
     * SltMdTyp：表格选择模式（0:选择行、1:选择格、2:带CheckBox的选择行）
     * sltMd：表格的行选择模式，0 单选 1 ：点击行进行多选  2：多选 按住ctrl或者shift多选
     */
    crtTblSltModel(moduleDesc) {
        let rowSelection = {};
        //单选多选
        var rowSMd = moduleDesc.rowSMd;
        if (!rowSMd || rowSMd == "0") {
            rowSelection.type = 'radio';//放弃不放
        } else if (rowSMd == 1 || rowSMd == 2) {
            rowSelection.type = 'checkbox';
            rowSelection.selectedRowKeys = [];
            rowSelection.columnWidth = '20px';
            this.state.rowSelection = rowSelection;
        }

    }


    /**
     * 表格基本属性
     * @param {*} moduleDesc
     * @param {*} tableColumn
     */
    AddTBAttribute(moduleDesc, tableProps) {

        // tableProps.scroll = {};
        // var ctlW = moduleDesc.ctlW; //form宽度
        // if (ctlW) tableProps.scroll.x = ctlW;
        // var ctlH = moduleDesc.ctlH; //form高度
        // if (ctlH) tableProps.scroll.y = ctlH;
        if (moduleDesc.isHeaders) tableProps.showHeader = !moduleDesc.isHeaders; //隐藏列头
        if (moduleDesc.isTbSpt) tableProps.bordered = moduleDesc.isTbSpt; //列线
        if (moduleDesc.te) tableProps.title = Resource.getTRByPrm(moduleDesc).te; //表头
        if (moduleDesc.isTtl) tableProps.showHeader = moduleDesc.isTtl; //是否显示表头
    }

    /**
     * 创建表格下部翻页工具条
     * @param {*} moduleDesc
     * @param {*} tableStore
     * @param {*} ws
     * @param {*} objFct
     */
    crtPgeBbar(moduleDesc, tableStore, objFct) {
        if (moduleDesc.isPg) {//是否带翻页控件
            let pgRows = moduleDesc.pgRows;
            if (!pgRows) { pgRows = 10 }
            let pagination = {
                total: tableStore.length,
                // current: 1,
                showSizeChanger: true,
                // showQuickJumper :true,
                // size:'small',
                pageSize: pgRows,
                // simple:true,
                onShowSizeChange: (current, pageSize) => {
                }
            };
            this.state.pagination = pagination;
        }
    }


    /**
     * 创建表格绑定store
     * @param {*} moduleDesc
     * @param {*} objFct
     * @param {*} ClmDes
     */
    getTBData(moduleDesc, objFct) {
        //取得绑定实例名
        var insName = moduleDesc.insName; //绑定实例名
        var tData;
        //取得绑定类名`  var tData = [];
        if (insName && objFct) {
            tData = objFct.get(insName);
        }
        if (!tData) {
            return [];
        }
        return tData;
    }

    /**
     * 创建表格 列头信息
     * @param {*} moduleDesc
     * @param {*} ClmDes
     * @param {*} objFct
     * @param {*} type
     */
    crtClmHead(moduleDesc, ClmDes, objFct, type) {
        //wangz追加 如果表格配置信息错误  自定义表头
        if (!ClmDes) {
            return;
        }
        var tableColumns = ClmDes.cldSet;
        var alwEdit = moduleDesc.isEd;
        var clm = this.crtTblClm(alwEdit, tableColumns, moduleDesc.insName, objFct, type);
        return clm;
    }

    /**
     * 获取表格 列头信息，如果列头是根树，则迭代遍历
     * 表格头数据
     */
    crtTblClm(alwEdit, tblClms, bdData, objFct, type) {
        var clms = [];
        console.log(tblClms);
        for (var i in tblClms) {
            var clm = {};
            var clmDes = tblClms[i];
            var cluW = clmDes.cluW;
            if (!cluW) {
                cluW = undefined; //默认大小
            }
            var text = clmDes.te;
            clm.title = text;
            clm.width = cluW; //设置列宽
            if (clmDes.isSt) {//该列是否可排序
                clm.sorter = (a, b) => {
                    return a.name.length - b.name.length;
                }
            }
            // clm.align = Ep.Utl.getClmAlg(clmDes.teAl); //设置列标题和数据的对其方式 0 :left 1:center 2;right
            // clm.hidden = clmDes.isHdn; //对应Ext是“是否隐藏”属性
            // clm.hideable = clmDes.HdAbl; //对应Ext是“是否隐藏”属性
            // clm.menuDisabled = clmDes.isCluMu; //是否显示列头菜单
            // clm.draggable = clmDes.isDgClu; //设置列头是否可以拖动，默认为true
            // clm.locked = clmDes.isLkClu; //表格是否可以锁定
            // clm.lockable = clmDes.isUnlkClu; //是否可通过列menu进行解锁
            // clm.groupable = clmDes.isGp; //设置在使用groupping分组特性的情况下是否禁止该列在标题菜单中等的分组功能
            // clm.flex = clmDes.cluSca; //列宽的比例
            // if (clmDes.fmter) {
            //     clm.formatter = clmDes.fmter;
            // }
            // //合计种类 summaryType sum
            // clm.summaryType = clmDes.smayType;
            // //合计函数 summaryRenderer
            // if (clmDes.smayFun) {
            //     var getTextStyle = new Function("value", "summaryData", "dataIndex", clmDes.smayFun);
            //     clm.summaryRenderer = getTextStyle;
            // }
            // clm.disIndex = clmDes.isdisIndex;//显示列  20170522增加-wangj
            // Ep.Utl.crtTblClmFmt(clm, clmDes, bdData, objFct, ws, type); //表格数据格式化展示
            // var isEditor = clmDes.isEd; //表格列是否可编辑
            // if (isEditor) {
            //     var ctlDes = clmDes.cldSet;
            //     if (ctlDes) {
            //         clm.editor = this.crtTblClmEditor(clmDes, bdData, objFct, ws, type);
            //     }

            // }
            // var childs = clmDes.cldSet;
            // if (clmDes.isGp && !this.isEmpty(childs) && childs.length > 0 && childs[0].desId === "EP_EO_TV_Node") {
            //     clm.columns = this.crtTblClm(alwEdit, childs, bdData, objFct, ws, type, true);
            // } else {
            //     clm.dataIndex = clmDes.c; //设置列与数据集中数据的对应关系值为数据模型中的字段名称
            // }
            clm.dataIndex = clmDes.c;
            clms[i] = clm;
        }
        return clms;
    }

    /**
     * 获取表格列描述信息
     * @param {描述信息} moduleDesc
     */
    getClmDes(moduleDesc) {
        //是否绑定表头了，绑定了继续
        var guid = moduleDesc.cluDes;
        if (!guid) {
            return;
        }
        //取得表头guid
        var ClmDes = PrmFactory.getPrm(guid);
        return ClmDes;
    }

    /**
     * [刷新表格控件]
     * @param  {[type]} tableData [表格数据对象数组]
     * @return {[type]}           [description]
     */
    refreshTable = (tableData) => {
        if (tableData) {
            this.state.dataSource = tableData;
            this.setState({ loading: true });
        }
    }

    refresh = () => {
        this.loaded = false;
        this.setState({ loading: false });
    }
    /**
     * [获取表格已选中/已勾选数据]
     * @return {[obj/list]} [已选中对象/已勾选行对象数组]
     */
    getTbSels = () => {
        return this.state.selectedRows;
    }
    /**
     * 获取表格所有数据
     * @return {[list]} [description]
     */
    getTbData = () => {
        return this.state.dataSource;
    }
    /**
     * 向表格中添加新数据
     * @param {[type]} newData [要添加的数据]
     */
    addTbNewData = (newData) => {
        if (newData) {
            this.setState({
                dataSource: [...this.state.dataSource, newData]
            });
        }
    }
    /**
     * 删除表格选中数据
     * @return {[type]} [description]
     */
    delTableSel = () => {
        var selectedRows = this.getTbSels();
        var dataSource = this.state.dataSource;
        if (dataSource && selectedRows) {
            selectedRows.map((item, index) => {
                for (var i = 0; i < dataSource.length; i++) {
                    if (item == dataSource[i]) {
                        dataSource.splice(i, 1);
                    }
                }
            });
            this.refreshTable(dataSource);
            this.state.selectedRows = [];//既然删除了那就置空喽
            if (this.state.rowSelection) {
                this.state.rowSelection.selectedRowKeys = [];
            }
            return dataSource;
        } else {
            return null;
        }
    }
    /**
     * 删除表格指定行数据
     * @param  {[type]} delData [description]
     * @return {[type]}          [description]
     */
    delTableObj = (delData) => {
        var dataSource = this.state.dataSource;
        if (dataSource && delData) {
            for (var i = 0; i < dataSource.length; i++) {
                if (delData == dataSource[i]) {
                    dataSource.splice(i, 1);
                }
            }
            this.refreshTable(dataSource);
            return dataSource;
        } else {
            return null;
        }
    }

    //渲染并返回一个虚拟DOM
    render = function () {

        if (!this.loaded) {
            var { panelModule, moduleDesc, bdInst, objFct, type } = this.props;
            //组装属性 初始化属性到this.state
            this.table_mk(panelModule, moduleDesc, bdInst, objFct, type);
            this.loaded = true;
        }

        return (
            <Table size="middle" {...this.state.tableProps} pagination={this.state.pagination} rowSelection={this.state.rowSelection}
                columns={this.state.columns} dataSource={this.state.dataSource} />
        );
    }
}
//给类添加公共方法
export { SgiTable };
