import React from 'react';
import ReactDOM from 'react-dom';
import { Tree } from 'antd';
import { addCtnCommonAttribute } from "./SgiCtnComm"
const TreeNode = Tree.TreeNode;
import { uuid } from "../sgiCommon/sgiCommon";
import { SgiEventHandler } from './SgiEventHandler';
import { sgiTreeBaseFun, sgiTreeNodeFun } from "./SgiTreeBaseFun"

const treeConfConstant = {
    childrenName: 'cldSet',
    key: '_key',
    pKey: '_pKey'
}

class SgiTree extends React.Component {

    static defaultProps = {
    };  // 注意这里有分号
    static propTypes = {
    };  // 注意这里有分号


    constructor(props) {
        super(props);
        //初始化state
        this.state = {
            loading: false,  //加载属性
            expandedKeys: [], //展开keys
            selectedKeys: [], //选中keys
            displayField: '',
            autoExpandParent: true, //自动展开父节点
            childrenName: treeConfConstant.childrenName,
            key: treeConfConstant.key,
            pKey: treeConfConstant.pKey,

            // treeProps: { style: { height: '100%' } }, //树基础属性
            treeProps: { style: {} }, //树基础属性
            treeData: [], //树的显示数据
            functions: {},
            selectedNodes: [], //已选中/勾选节点list

            // treeStructureData: [] //[{key:'',pKey:'',data:{}}]
        };
    }

    //根据id获取数据
    /**
     * 根据唯一标示，从数据中找到相应的组件数据
     * @param {*} rootChildren
     * @param {*} dnd_id
     */
    findNodeByKey = function (rootChildren, key) {
        if (!rootChildren) {
            rootChildren = this.state.treeData;
        }
        if (!key) {
            return;
        }
        for (let i = 0; i < rootChildren.length; i++) {
            let tmpNode = rootChildren[i];
            let tmp_dnd_id = tmpNode[this.state.key];
            if (key === tmp_dnd_id) {
                return tmpNode;
            }
            if (tmpNode[this.state.childrenName] && tmpNode[this.state.childrenName].length > 0) {
                let result = this.findNodeByKey(tmpNode[this.state.childrenName], key);
                if (result) return result;
            }
        }
    }

    /**
     * 根据描述创建文本框
     * @param {父组件} panelModule
     * @param {组件描述} moduleDesc
     * @param {绑定实例ID} bdInst
     * @param {对象工厂} objFct
     * @param {make类型} type
     */
    tree_mk(panelModule, moduleDesc, bdInst, objFct, type) {

        //获取需要展示的数据信息
        if (!moduleDesc) {
            return;
        }
        //绑定数据，创建表格store 搜索条、翻页控件需要使用该信息，所以先创建
        var tableStore = this.getTreeData(moduleDesc, objFct);
        this.state.treeData = tableStore;
        //显示信息
        this.state.displayField = moduleDesc.c ? moduleDesc.c : 'te';
        //转换基础属性
        this.AddTreeAttribute(moduleDesc, this.state.treeProps);
        //转换form公共属性
        addCtnCommonAttribute(this, moduleDesc, this.state.treeProps);
        //绑定事件
        this.bindEvent(moduleDesc, this.state.treeProps, this.state.functions, type);
    }


    /**
     * 绑定事件
     * @param {*} moduleDesc
     * @param {*} treeProps
     */
    bindEvent(moduleDesc, treeProps, functions, type) {
        //拖拽模式 不生成事件
        var iCLsn = moduleDesc.iCLsn; // 用户自定义点击事件
        if (iCLsn && type != 'dnd') {
            var $iCLsn = new Function("module", "objFct", "record", "treeNode", "e", iCLsn);
            functions.onSelect = $iCLsn;
        }
        //moduleDesc.ndIsChk:是否可以多选
        if (moduleDesc.ndIsChk) {
            treeProps.onCheck = SgiEventHandler.itemclick.bind(this);
        } else {
            treeProps.onSelect = SgiEventHandler.itemclick.bind(this);
        }

        treeProps.onExpand = (expandedKeys) => {
            this.state.expandedKeys = expandedKeys;
            this.state.autoExpandParent = true;
            this.setState({ loading: false });
            console.log('expandedKeys', expandedKeys);
        }
    }

    /**
    * 创建表格绑定store
    * @param {*} moduleDesc
    * @param {*} objFct
    * @param {*} ClmDes
    */
    getTreeData(moduleDesc, objFct) {
        //取得绑定实例名
        var insName = moduleDesc.insName; //绑定实例名
        var tData;
        //取得绑定类名`  var tData = [];
        if (insName && objFct) {
            tData = objFct.get(insName);
        }
        if (!tData) {
            return [];
        }
        return tData;
    }

    /**
     * 创建树视图
     */
    AddTreeAttribute(moduleDesc, treeProps) {

        // treeProps.checkStrictly = true; //父子节点点击分开
        if (moduleDesc.ndisLine) {
            treeProps.showLine = true; //树节点是否连线
        } else {
            treeProps.showLine = false; //树节点是否连线
        }
        if (moduleDesc.ndIsChk) {
            treeProps.checkable = true; // 树节点是否可选
        } else {
            treeProps.checkable = false; // 树节点是否可选
        }
        if (moduleDesc.ndIsDg) {
            treeProps.draggable = true; // 树节点是否可拖拽
        } else {
            treeProps.draggable = false; // 树节点是否可拖拽
        }

        // clpDrt:"top", // 面板的折叠方向
        // clpd:false, // 面板初始时的折叠状态
        // disCustom:false, //只显示自定义菜单
        // isClp:false, // 面板是否可以折叠
        // isClpFst:true, // 是否面板展开或收缩的顺序
        // isCls:false, // 面板是否可以关闭
        // isFrm:false, // 面板是否填充
        // isHClpTl:false, // 是否显示折叠按钮
        // isMsMu:false, //使用右键菜单
        // isTlb:false, //显示工具条
        // isttlClp:false, // 是否单击面板头部折叠
        // tlbIsTtl:true, //显示标题
        // ttlAlg:"top", // 面板标题位置
        // ttlAlgn:"left", // 面板标题对齐方式
        // selFirst:false, //初始化后选择首行
        // 可设置默认选中的树节点：defaultSelectedKeys，（受控）设置选中的树节点：selectedKeys
    }

    // 定义树节点对象，追加常用方法
    fitTreeNodes = (data, parentNode) => data.map((item) => {
        if (!item[treeConfConstant.key]) {
            item[treeConfConstant.key] = uuid(6);
        }
        item[treeConfConstant.pKey] = parentNode ? parentNode.props.itemData[this.state.key] : null;
        let childrenName = this.state.childrenName;

        if (item[childrenName] && item[childrenName].length) {
            let children = [];
            let currentNode = <TreeNode itemData={item} tree={this} parentNode={parentNode} key={item[treeConfConstant.key]} {...sgiTreeNodeFun} title={item[this.state.displayField]}>{children}</TreeNode>
            children.push(this.fitTreeNodes(item[childrenName], currentNode));
            return currentNode;
        }
        return <TreeNode itemData={item} tree={this} parentNode={parentNode} key={item[treeConfConstant.key]} {...sgiTreeNodeFun} title={item[this.state.displayField]} isLeaf />;
    });

    refresh = () => {
        this.loaded = false;
        this.setState({ loading: false });
    }


    //渲染并返回一个虚拟DOM
    render = function () {

        if (!this.loaded) {
            var { panelModule, moduleDesc, bdInst, objFct, type } = this.props;
            //组装属性
            this.tree_mk(panelModule, moduleDesc, bdInst, objFct, type);
            this.loaded = true;
        }

        return (
            <Tree {...this.state.treeProps} selectedKeys={this.state.selectedKeys} expandedKeys={this.state.expandedKeys}
                checkedKeys={this.state.checkedKeys} autoExpandParent={this.state.autoExpandParent}>
                {this.fitTreeNodes(this.state.treeData, null)}
            </Tree>
        );
    }
}

//给类添加公共方法
Object.assign(SgiTree.prototype, sgiTreeBaseFun);

export { SgiTree };
