'use strict';

import React from 'react';
import ReactDOM from 'react-dom';
import { Form, Row, Col, Input } from 'antd';
import { Checkbox, InputNumber, Tabs, Collapse, Select } from 'antd';

const FormItem = Form.Item;
const TabPane = Tabs.TabPane;
const { TextArea } = Input;
const Panel = Collapse.Panel;
const Option = Select.Option;

const formItemLayout = {
    labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
    },
    wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
    },
};

var textOnChange = (currentModule, attname, e, e2)=>{
    let value = e.target.value;
    currentModule.refresh(attname, value);
}

var numberOnChange = (currentModule, attname, e)=>{
    let value = e;
    currentModule.refresh(attname, value);
}

var selectOnChange = (currentModule, attname, value)=>{//change传入对象为value
    currentModule.refresh(attname, value);
}

var checkOnChange = (currentModule, attname, e)=>{
    let value = e.target.checked;
    currentModule.refresh(attname, value);
}

var getCommAttEditor = (currentModule)=>{
    return(
        <Form>
            <Row>
                <Col span={8}>
                    <FormItem {...formItemLayout} label={"显示名称"}>
                        <Input value={currentModule.state.values.te} onChange={textOnChange.bind(this, currentModule, 'te')} />
                    </FormItem>
                </Col>
                <Col span={4}>
                    <FormItem labelCol={{ span: 18 }} label={"允许为空"}>
                        <Checkbox checked={currentModule.state.values.alwBlk} onChange={checkOnChange.bind(this, currentModule, 'alwBlk')} />
                    </FormItem>
                </Col>
                <Col span={4}>
                    <FormItem labelCol={{ span: 18 }} label={"禁用"}>
                        <Checkbox checked={currentModule.state.values.isDis} onChange={checkOnChange.bind(this, currentModule, 'isDis')} />
                    </FormItem>
                </Col>
                <Col span={4}>
                    <FormItem labelCol={{ span: 18 }} label={"隐藏"}>
                        <Checkbox checked={currentModule.state.values.isHdn} onChange={checkOnChange.bind(this, currentModule, 'isHdn')} />
                    </FormItem>
                </Col>
                <Col span={4}>
                    <FormItem labelCol={{ span: 18 }} label={"隐藏标签"}>
                        <Checkbox checked={currentModule.state.values.isLbl} onChange={checkOnChange.bind(this, currentModule, 'isLbl')} />
                    </FormItem>
                </Col>
            </Row>
            <Row>
                <Col span={8}>
                    <FormItem {...formItemLayout} label={"编码"}>
                        <Input value={currentModule.state.values.c} onChange={textOnChange.bind(this, currentModule, 'c')} />
                    </FormItem>
                </Col>
                <Col span={4}>
                    <FormItem labelCol={{ span: 18 }} wrapperCol={{ span: 6 }} label={"标签宽度"}>
                        <InputNumber defaultValue={0} value={currentModule.state.values.lblW} onChange={numberOnChange.bind(this, currentModule, 'lblW')} />
                    </FormItem>
                </Col>
                <Col span={4}>
                    <FormItem labelCol={{ span: 18 }} wrapperCol={{ span: 6 }} label={"组件宽度"}>
                        <InputNumber defaultValue={0} value={currentModule.state.values.ctlW} onChange={numberOnChange.bind(this, currentModule, 'ctlW')} />
                    </FormItem>
                </Col>
                <Col span={4}>
                    <FormItem labelCol={{ span: 18 }} wrapperCol={{ span: 6 }} label={"组件高度"}>
                        <InputNumber defaultValue={0} value={currentModule.state.values.ctlH} onChange={numberOnChange.bind(this, currentModule, 'ctlH')} />
                    </FormItem>
                </Col>
            </Row>
            <Row>
                <Col span={8}>
                    <FormItem {...formItemLayout} label={"控件id"}>
                        <Input value={currentModule.state.values.cId} onChange={textOnChange.bind(this, currentModule, 'cId')} />
                    </FormItem>
                </Col>

                <Col span={8}>
                    <FormItem {...formItemLayout} label={"标签位置"} >
                        <Select value={currentModule.state.values.lbAlg||"hehe"} onChange={selectOnChange.bind(this, currentModule, 'lbAlg')}>
                            <Option value="left">靠左</Option>
                            <Option value="center">居中</Option>
                            <Option value="right">靠右</Option>
                            <Option value="hehe">未实现</Option>
                        </Select>
                    </FormItem>
                </Col>
                <Col span={8}>
                    <FormItem {...formItemLayout} label={"文本后信息"}>
                        <Input value={currentModule.state.values.bdText} onChange={textOnChange.bind(this, currentModule, 'bdText')} />
                    </FormItem>
                </Col>
            </Row>
            <Row>
                <Col span={16}>
                    <FormItem labelCol={{ span: 4 }} wrapperCol={{ span: 20 }} label={"输入提示文本"}>
                        <Input value={currentModule.state.values.inpPopTe} onChange={textOnChange.bind(this, currentModule, 'inpPopTe')} />
                    </FormItem>
                </Col>
                <Col span={8}>
                    <FormItem {...formItemLayout} label={"初始值"}>
                        <Input value={currentModule.state.values.defVal10} onChange={textOnChange.bind(this, currentModule, 'defVal10')} />
                    </FormItem>
                </Col>
            </Row>
            <Row>
                <Col span={8}>
                    <FormItem {...formItemLayout} label={"最小长度"}>
                        <InputNumber defaultValue={0} value={currentModule.state.values.minL} onChange={numberOnChange.bind(this, currentModule, 'minL')} />
                    </FormItem>
                </Col>
                <Col span={8}>
                    <FormItem {...formItemLayout} label={"最大长度"}>
                        <InputNumber defaultValue={0} value={currentModule.state.values.maxL} onChange={numberOnChange.bind(this, currentModule, 'maxL')} />
                    </FormItem>
                </Col>
            </Row>
        </Form >
    );
}

var getFunEditor = (currentModule)=>{
    return(
        <Collapse defaultActiveKey={['2']} accordion>
            <Panel header="进入事件" key="1">
                <TextArea value={currentModule.state.values.inLsn} style={{ height: '300px' }} onChange={textOnChange.bind(this, currentModule, 'inLsn')} />
            </Panel>
            <Panel header="修改事件" key="2">
                <TextArea value={currentModule.state.values.chgLsn} style={{ height: '300px' }} onChange={textOnChange.bind(this, currentModule, 'chgLsn')} />
            </Panel>
            <Panel header="离开事件" key="3">
                <TextArea value={currentModule.state.values.lveLsn} style={{ height: '300px' }} onChange={textOnChange.bind(this, currentModule, 'lveLsn')} />
            </Panel>
        </Collapse>
    );
}

var getShowEditor = (attEditor, funEditor)=>{
    return(
        // <div style={{ height: '500px', overflow: 'auto' }}>
            <Tabs defaultActiveKey="1">
                <TabPane tab="属性编辑" key="1">{attEditor}</TabPane>
                <TabPane tab="绑定事件" key="2">{funEditor}</TabPane>
            </Tabs>
        // </div>
    );
}

export { getCommAttEditor, getFunEditor, getShowEditor,
    formItemLayout, textOnChange, numberOnChange, selectOnChange, checkOnChange };