'use strict';

import React from 'react';
import ReactDOM from 'react-dom';
import { Modal, Form, Row, Col, Input, Button, Icon } from 'antd';
import { Checkbox, InputNumber, Select, Table, Popconfirm } from 'antd';
import { Radio } from 'antd';
const RadioGroup = Radio.Group;
import { Layout } from 'antd';
const { Header, Footer, Sider, Content } = Layout;
const FormItem = Form.Item;
const { Column, ColumnGroup } = Table;
import { Tabs } from 'antd';
const TabPane = Tabs.TabPane;
import { Collapse } from 'antd';
const { TextArea } = Input;
const Panel = Collapse.Panel;
import { updateUIJson } from './DndDispatch'
import { copyArr, Array, uuid } from "../sgiCommon/sgiCommon";


const formItemLayout = {
    labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
    },
    wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
    },
};


const rowSelection = {
    onChange: (selectedRowKeys, selectedRows) => {
        console.log(`selectedRowKeys: ${selectedRowKeys}`, 'selectedRows: ', selectedRows);
    },
    onSelect: (record, selected, selectedRows) => {
        console.log(record, selected, selectedRows);
    },
    onSelectAll: (selected, selectedRows, changeRows) => {
        console.log(selected, selectedRows, changeRows);
    },
};



class Dnd_SgiTableColumnsEditor extends React.Component {

    constructor(props) {
        super(props);
        let currentCtl = this.props.currentCtl;
        var { panelModule, moduleDesc, bdInst, objFct, type } = currentCtl.props;
        this.state = {
            loading: false,
            visible: false, //弹出框默认不显示
            btnEditorVisible: "none", //按钮编辑弹出框默认不显示            
            values: {},
            store: moduleDesc['dnd_columns'] ? moduleDesc['dnd_columns'] : [],
            addFlag: 'add'
        };
        // this.state.store =
    }

    refresh(attname, value) {
        this.state.values[attname] = value;
        this.setState({ loading: false });
    }

    textOnChange(attname, e, e2) {
        let value = e.target.value;
        this.refresh(attname, value);
    }

    radioOnChange(attname, e, e2) {
        let value = e.target.value;

        this.modifyBtnEditorVisible(value);

        this.refresh(attname, value);
    }

    modifyBtnEditorVisible(value) {
        if ('opt' == value) {
            this.state.btnEditorVisible = undefined;
        } else {
            this.state.btnEditorVisible = 'none'
        }
    }

    numberOnChange(attname, e) {
        let value = e;
        this.refresh(attname, value);
    }

    checkOnChange(attname, e) {
        let value = e.target.checked;
        this.refresh(attname, value);
    }

    handleCancel = () => {
        this.setState({ visible: false });
    }

    handleOk = () => {
        if (this.state.addFlag == 'add') {
            this.state.store.push(this.state.values);
        } else if (this.state.addFlag == 'addSon') {
            if (!this.state.addRecord.children) {
                this.state.addRecord.children = [];
            }
            this.state.addRecord.children.push(this.state.values);
        }
        this.setState({ visible: false });

        this.commonRefresh();
    }

    //树表 给数据追加KEY
    fitKeyForStore(store, pkey) {
        if (!store || store.length < 1) {
            return;
        }
        store.forEach(element => {
            if (!element.key) {
                element.key = uuid(6);
            }
            element.pkey = pkey;
            if (element.children) {
                this.fitKeyForStore(element.children, element.key);
            }
        });
    }

    commonRefresh() {
        let currentCtl = this.props.currentCtl;
        var { panelModule, moduleDesc, bdInst, objFct, type } = currentCtl.props;
        moduleDesc['dnd_columns'] = this.state.store;
        //组装属性 初始化属性到this.state
        currentCtl.refs.Dnd_SgiTable_SgiTable.refresh();

        //修改描述信息
        updateUIJson(moduleDesc.dnd_id, "dnd_columns", copyArr(this.state.store));
    }

    openModal = () => {
        this.setState({ visible: true });
    }

    addColumn = () => {
        this.state.addFlag = 'add';
        this.state.values = { clmType: 'clm' };
        this.modifyBtnEditorVisible('clm');
        this.openModal();
    }

    addSonColumn = (text, record, index) => {
        this.state.addFlag = 'addSon';
        this.state.values = { clmType: 'clm' };
        this.modifyBtnEditorVisible(record.clmType);
        this.state.addRecord = record;
        this.openModal();
    }

    modifyColumn = (text, record, index) => {
        this.state.addFlag = 'modify';
        this.state.values = record;
        this.modifyBtnEditorVisible(record.clmType);
        this.openModal();
    }

    deleteColumn = (text, record, index) => {
        //从store中删除数据
        //根据record的pkey查询找到上级节点
        let dataStore = this.getPRecord(this.state.store, record.pkey);
        Array.removeIndex(dataStore, index);
        this.setState({ loading: false });

        this.commonRefresh();
    }

    getPRecord(dataList, pkey) {
        if (!pkey) {
            return dataList;
        }
        let tmp;
        for (var i = 0; i < dataList.length; i++) {
            tmp = dataList[i];
            if (tmp.pkey == pkey) {
                return dataList;
            }
            if (tmp.children && tmp.children.length) {
                return this.getPRecord(tmp.children, pkey);
            }
        }
    }

    render() {
        let currentCtl = this.props.currentCtl;
        this.fitKeyForStore(this.state.store, null); //添加KEY

        const columns = [{
            title: '列名',
            dataIndex: 'title',
            key: 'title',
        }, {
            title: '列key',
            dataIndex: 'dataIndex',
            key: 'dataIndex',
            // width: '12%',
        }, {
            title: '列类型',
            dataIndex: 'clmType',
            key: 'clmType',
            render: (text, record, index) => {
                if (text == 'clm') {
                    return '普通列';
                } else if (text == 'opt') {
                    return '操作列';
                } else if (text == 'optGroup') {
                    return '操作列组';
                }
            }
            // width: '12%',
        }, {
            title: '操作',
            dataIndex: 'action',
            // width: '30%',
            key: 'action',
            render: (text, record, index) => (
                <span>
                    <Button style={{ margin: "0px 10px 0px 0px" }} icon={'plus-square-o'} onClick={this.addSonColumn.bind(this, text, record, index)} >
                        添加子列
                    </Button>
                    <Button style={{ margin: "0px 10px 0px 0px" }} icon={'edit'} onClick={this.modifyColumn.bind(this, text, record, index)} >
                        修改
                    </Button>
                    <Popconfirm title="确定删除?" onConfirm={this.deleteColumn.bind(this, text, record, index)}>
                        <Button style={{ margin: "0px 10px 0px 0px" }} icon={'delete'}>删除</Button>
                    </Popconfirm>
                </span>
            )
        }];

        let columnEditor = (
            <Table size="middle" dataSource={this.state.store} columns={columns} rowSelection={rowSelection}>
            </Table>
        )

        let attEditor = (
            <Form>
                <Row>
                    <Col span={16}>
                        <FormItem labelCol={{ span: 4 }} wrapperCol={{ span: 20 }} label={"列种类"}>
                            <RadioGroup defaultValue={'clm'} onChange={this.radioOnChange.bind(this, 'clmType')} value={this.state.values.clmType}>
                                <Radio value={'clm'}>普通列</Radio>
                                <Radio value={'opt'}>操作列</Radio>
                                <Radio value={'optGroup'}>操作列组</Radio>
                            </RadioGroup>
                        </FormItem>
                    </Col>
                </Row>
                <Row>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"列名"}>
                            <Input value={this.state.values.title} onChange={this.textOnChange.bind(this, 'title')} />
                        </FormItem>
                    </Col>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"列key"}>
                            <Input value={this.state.values.dataIndex} onChange={this.textOnChange.bind(this, 'dataIndex')} />
                        </FormItem>
                    </Col>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"列宽度"}>
                            <Input value={this.state.values.width} onChange={this.textOnChange.bind(this, 'width')} />
                        </FormItem>
                    </Col>
                </Row>
                <Row style={{ display: this.state.btnEditorVisible }}>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"按钮名称"}>
                            <Input value={this.state.values.btnName} onChange={this.textOnChange.bind(this, 'btnName')} />
                        </FormItem>
                    </Col>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"图片(参照文档)"}>
                            <Input value={this.state.values.btnIcon} onChange={this.textOnChange.bind(this, 'btnIcon')} />
                        </FormItem>
                    </Col>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"操作样式"}>
                            <RadioGroup defaultValue={'btn'} onChange={this.textOnChange.bind(this, 'optType')} value={this.state.values.optType}>
                                <Radio value={'btn'}>按钮</Radio>
                                <Radio value={'href'}>超链接</Radio>
                            </RadioGroup>
                        </FormItem>
                    </Col>
                </Row>
                <Row style={{ display: this.state.btnEditorVisible }}>
                    <FormItem label={"点击事件(module,objFct,record,index)"}>
                        <TextArea value={this.state.values.iCLsn} style={{ height: '240px' }} onChange={this.textOnChange.bind(this, 'iCLsn')} />
                    </FormItem>
                </Row>
            </Form >
        )

        let funEditor = (
            <Panel header="生成复杂数据的渲染函数" style={{ height: '100%' }}>
                <TextArea placeholder={'Function(text, record, index) {}<br>'}
                    value={this.state.values.render} style={{ height: '300px' }} onChange={this.textOnChange.bind(this, 'render')} />
            </Panel>
        )

        return (
            <div style={{ height: '420px', overflow: 'auto' }}>
                <Layout style={{ height: '100%' }}>
                    {/* <Sider style={{ background: 'white', border: '1px solid rgb(217, 217, 217)' }}>列的结构树状的，暂时还没想好</Sider> */}
                    <Layout style={{ height: '100%' }} >
                        <Header style={{ padding: '0 20px', background: 'white', border: '1px solid rgb(217, 217, 217)' }}>
                            <Button type="primary" style={{ margin: '0 10px 0 0' }} onClick={this.addColumn.bind(this)}>添加列</Button>
                            {/* <Button type="primary" style={{ margin: '0 10px 0 0' }} onClick={this.modifyColumn.bind(this)}>修改列信息</Button> */}
                        </Header>
                        <Content style={{ background: 'white', border: '1px solid rgb(217, 217, 217)' }}>
                            {columnEditor}
                        </Content>
                    </Layout>
                </Layout>
                <Modal
                    title='列信息'
                    visible={this.state.visible}
                    onCancel={this.handleCancel}
                    width='1000px'
                    height='800px'
                    // footer={null}
                    onOk={this.handleOk}
                    onCancel={this.handleCancel}
                >
                    <Tabs defaultActiveKey="1" style={{ height: '500px' }}>
                        <TabPane tab="属性编辑" key="1">{attEditor}</TabPane>
                        {/* <TabPane tab="操作列及事件" key="2">{funEditor}</TabPane> */}
                    </Tabs>
                </Modal>
            </div>
        )
    }
}

export { Dnd_SgiTableColumnsEditor };