'use strict';

import React from 'react';
import ReactDOM from 'react-dom';
import { Form, Row, Col, Input, Button, Icon } from 'antd';
import { Checkbox, InputNumber, Select } from 'antd';
const FormItem = Form.Item;
import { Tabs } from 'antd';
const TabPane = Tabs.TabPane;
import { Collapse } from 'antd';
const { TextArea } = Input;
const Panel = Collapse.Panel;
import { updateUIJson } from './DndDispatch'

const formItemLayout = {
    labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
    },
    wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
    },
};

class Dnd_SgiTabsEditor extends React.Component {

    constructor(props) {
        super(props);
        this.state = { loading: false };
        // this.state.values = this.props.values;
        // console.log(this.state.values);
    }

    refresh() {
        this.setState({ loading: false });
    }

    setValues(values) {
        this.setState(values);
    }

    textOnChange(attname, e, e2) {
        let value = e.target.value;
        this.refresh(attname, value);
    }

    numberOnChange(attname, e) {
        let value = e;
        this.refresh(attname, value);
    }

    checkOnChange(attname, e) {
        let value = e.target.checked;
        this.refresh(attname, value);
    }

    refresh(attname, value) {
        this.state.values[attname] = value;
        this.setState({ loading: false });

        let currentCtl = this.props.currentCtl;
        var { panelModule, moduleDesc, bdInst, objFct, type } = currentCtl.props;
        moduleDesc[attname] = value;
        //组装属性 初始化属性到this.state
        currentCtl.refs.Dnd_SgiTabs_SgiTabs.refresh();

        //修改描述信息
        updateUIJson(moduleDesc.dnd_id, attname, value);
    }

    render() {
        // console.log('textEditorRender');
        this.state.values = this.props.values;
        let attEditor = (
            <Form>
                <Row>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"组件ID"}>
                            <Input value={this.state.values.cId} onChange={this.textOnChange.bind(this, 'cId')} />
                        </FormItem>
                    </Col>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"名称"}>
                            <Input value={this.state.values.n} onChange={this.textOnChange.bind(this, 'n')} />
                        </FormItem>
                    </Col>
                    <Col span={4}>
                        <FormItem labelCol={{ span: 18 }} label={"显示边框"}>
                            <Checkbox checked={this.state.values.isBrdr} onChange={this.checkOnChange.bind(this, 'isBrdr')} />
                        </FormItem>
                    </Col>
                </Row>
                <Row>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"选项卡位置"}>
                            <Select defaultValue="top" value={this.state.values.tabPst} onChange={this.numberOnChange.bind(this, 'tabPst')}>
                                <Option value="top">top</Option>
                                <Option value="bottom">bottom </Option>
                                <Option value="left">left</Option>
                                <Option value="right">right </Option>
                            </Select>
                        </FormItem>
                    </Col>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"初始激活选项卡"}>
                            <Input value={this.state.values.atvTab} onChange={this.textOnChange.bind(this, 'atvTab')} />
                        </FormItem>
                    </Col>
                </Row>
                <Row>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"组件宽度"}>
                            <Input value={this.state.values.ctlW} onChange={this.textOnChange.bind(this, 'ctlW')} />
                        </FormItem>
                    </Col>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"组件高度"}>
                            <Input value={this.state.values.ctlH} onChange={this.textOnChange.bind(this, 'ctlH')} />
                        </FormItem>
                    </Col>
                </Row>
                <Row>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"外边距"}>
                            <Input value={this.state.values.mgn} onChange={this.textOnChange.bind(this, 'mgn')} />
                        </FormItem>
                    </Col>
                    <Col span={8}>
                        <FormItem {...formItemLayout} label={"内边距"}>
                            <Input value={this.state.values.pad} onChange={this.textOnChange.bind(this, 'pad')} />
                        </FormItem>
                    </Col>
                </Row>
            </Form >
        )

        let funEditor = (
            <Collapse defaultActiveKey={['1']} accordion>
                <Panel header="切换事件" key="1">
                    <TextArea value={this.state.values.tabLsn} style={{ height: '300px' }} onChange={this.textOnChange.bind(this, 'tabLsn')} />
                </Panel>
            </Collapse>
        )

        return (
            <div style={{ height: '500px', overflow: 'auto' }}>
                <Tabs defaultActiveKey="1">
                    <TabPane tab="属性编辑" key="1">{attEditor}</TabPane>
                    <TabPane tab="绑定事件" key="2">{funEditor}</TabPane>
                </Tabs>
            </div>
        )
    }
}

export { Dnd_SgiTabsEditor };