/*   参数工厂
 --------------------------------------------------------------------------------
 作者：王哲                           创建日期：2018/03/12
 --------------------------------------------------------------------------------
 提供方法列表：
 ★对象保存
 ★对象读取
 ★根据参数guid创建对象
 ★对象删除
 --------------------------------------------------------------------------------
 修改：                               修改日期：
 修改内容:

 --------------------------------------------------------------------------------

 *******************************************************************************/

import { GUID } from '../sgiCommon/sgiCommonConstant'
import * as sgiCommon from '../sgiCommon/sgiCommon'
import { sgiLocalStorage } from './localStorage'
import { sgiPfClient, sgiUrl } from '../sgiCommon/sgiClient'


const cacheFlag = false;

window.PrmFactory = {
	/**
     * 获取参数
     *  @param {string} guid 参数唯一key
     *  @param {boolean} fromserver	强制从服务端获取参数标志，true表示强制从服务端获取
     *  @return 参数
     *
     */
    getPrm: function (guid, fromserver) {
        if (!guid) {
            return null;
        }
        if (typeof guid != 'string' || guid.constructor != String) {
            return null;
        }
        var ms = guid.split("`");
        var mguid = ms[0];
        var strJson = null;
        if (!fromserver && cacheFlag) {
            strJson = this.getPrmCache(mguid);
        }
        var json = {};
        if (!strJson) {
            strJson = sgiPfClient.restcall(sgiUrl.pf + "/prm/" + guid, "GET", {}, false);
            if (strJson && typeof strJson != "object") {
                json = sgiCommon.strToJson(strJson);
            }
        } else {
            json = sgiCommon.strToJson(strJson);
        }
        if (!json) {
            return null;
        }
        var length = ms.length;
        for (var i = 1; i < length; i++) {
            json = this.findMenber(json, ms[i]);
        }
        return json;
    },
    /**
     * 保存参数方法
     *  @param root 需要保存的参数对象
     *  @return
     *  0  ： 成功
     * -1  ： 失败
     */
    save: function (root) {
        if (!root) {
            return -1;
        }
        if (!root && typeof root !== "object") {
            return -1;
        }
        var guid = this.makeGUID(root);

        //		var version = root.prmVsn;
        //		if(!version){
        //			root.auth = "";
        //			root.crtTm = "";
        //			root.prmVsn = 0;
        //			root.edAuth = "";
        //			root.edTm = "";
        //		}

        var data = {};
        data.root = sgiCommon.jsonToStr(root);
        var result = sgiPfClient.restcall(sgiUrl.pf + "/prm/" + guid, "PUT", data);

        if (result == 1) {
            console.log("提示:参数冲突.已经有人修改了该参数，请刷新");
            return 1;
        }
        if (result != 0) {
            console.log("提示:不等于0不等于0不等于0，请刷新");
            return -1;
        }
        var newprm = this.getPrm(guid, true);

        if (cacheFlag) {
            this.saveLocal(guid, data.root);//json
        }
        return newprm;
    },

    /**
     * 获取指定系统下的参数
     */
    getPrmBySS: function (ap, tt, ss) {
        if (!ap && !tt && !ss) {
            return null;
        }
        var data = {};
        var result = sgiPfClient.restcall(sgiUrl.pf + "/prm/" + "ap/" + ap + "/tt/" + tt + "/ss/" + ss, "GET", data);
        var prms = new Array();;
        if (result) {
            result = sgiCommon.strToJson(result);
            result.forEach(function (strJson, index) {
                let json = sgiCommon.strToJson(strJson);
                prms.push(json);
            });
        }
        return prms;
    },
    /**
     * 删除指定参数
     */
    remove: function (guid) {
        if (!guid) {
            return -1;
        }
        if (typeof guid != 'string' || guid.constructor != String) {
            return -1;
        }
        var ms = guid.split("`");
        var mguid = ms[0];
        var result = sgiPfClient.restcall(sgiUrl.pf + "/prm/" + guid, "DELETE", {}, false);
        if (result == 0) {
            if (cacheFlag) {
                this.deleteLocal(guid);
            }
        }
        return result;
    },

    getPrmCache: function (guid) {
        return sgiLocalStorage.get(guid);
    },
    saveLocal: function (guid, json) {
        sgiLocalStorage.set(guid, json);
    },
    deleteLocal: function (guid) {
        sgiLocalStorage.remove(guid);
    },

    makeGUID: function (root) {
        var ap, tt, ss, sc;
        ap = root.ap;
        tt = root.tt;
        ss = root.ss;
        sc = root.sc;
        if (!(ap && tt && ss && sc)) {
            return null;
        }
        var guid = ap + GUID.SP + tt + GUID.SP + ss + GUID.SP + sc;
        return guid;
    },
    findMenber: function (json, sc) {
        if (!json) {
            return null;
        }
        var children = json.cldSet;
        if (!children)
            return null;
        var count = children.length;
        for (var i = 0; i < count; i++) {
            if (children[i].sc === sc) {
                json = children[i];
                break;
            }
        }
        return json;
    }
}

export { PrmFactory };
